@@ -1,7 +1,7 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: i_sound.c,v 1.16.2.3 2001/10/04 07:26:14 proff_fs Exp $
+ * $Id: i_sound.c,v 1.16.2.5 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -9,7 +9,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -22,17 +22,17 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
- *	System interface for sound.
+ *  System interface for sound.
  *
  *-----------------------------------------------------------------------------
  */
 
 static const char
-rcsid[] = "$Id: i_sound.c,v 1.16.2.3 2001/10/04 07:26:14 proff_fs Exp $";
+rcsid[] = "$Id: i_sound.c,v 1.16.2.5 2002/07/20 18:08:37 proff_fs Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "../config.h"
@@ -85,14 +85,14 @@ int mus_card = 1;
 int detect_voices = 0; // God knows
 
 // Needed for calling the actual sound output.
-static int SAMPLECOUNT=		512;
+static int SAMPLECOUNT=   512;
 #define MAX_CHANNELS    32
 
 // MWM 2000-01-08: Sample rate in samples/second
 int snd_samplerate=11025;
 
 // The actual output device.
-int	audio_fd;
+int audio_fd;
 
 typedef struct {
   // SFX id of the playing sound effect.
@@ -120,14 +120,14 @@ typedef struct {
 channel_info_t channelinfo[MAX_CHANNELS];
 
 // Pitch to stepping lookup, unused.
-int		steptable[256];
+int   steptable[256];
 
 // Volume lookups.
-int		vol_lookup[128*256];
+int   vol_lookup[128*256];
 
-/* cph 
+/* cph
  * stopchan
- * Stops a sound, unlocks the data 
+ * Stops a sound, unlocks the data
  */
 
 static void stopchan(int i)
@@ -148,8 +148,8 @@ static void stopchan(int i)
 //
 int addsfx(int sfxid, int channel)
 {
-    int		oldest = gametic;
-    int		oldestnum = 0;
+    int   oldest = gametic;
+    int   oldestnum = 0;
 
   stopchan(channel);
 
@@ -162,7 +162,7 @@ int addsfx(int sfxid, int channel)
       /* Find padded length */
     len -= 8;
     channelinfo[channel].data = W_CacheLumpNum(lump);
-      
+
       /* Set pointer to end of raw data. */
     channelinfo[channel].enddata = channelinfo[channel].data + len - 1;
     channelinfo[channel].samplerate = (channelinfo[channel].data[3]<<8)+channelinfo[channel].data[2];
@@ -183,8 +183,8 @@ int addsfx(int sfxid, int channel)
 static void updateSoundParams(int handle, int volume, int seperation, int pitch)
 {
   int slot = handle;
-    int		rightvol;
-    int		leftvol;
+    int   rightvol;
+    int   leftvol;
     int         step = steptable[pitch];
 
 #ifdef RANGECHECK
@@ -211,15 +211,15 @@ static void updateSoundParams(int handle, int volume, int seperation, int pitch)
     volume *= 8;
     leftvol = volume - ((volume*seperation*seperation) >> 16);
     seperation = seperation - 257;
-    rightvol= volume - ((volume*seperation*seperation) >> 16);	
+    rightvol= volume - ((volume*seperation*seperation) >> 16);
 
     // Sanity check, clamp volume.
     if (rightvol < 0 || rightvol > 127)
-	I_Error("rightvol out of bounds");
-    
+  I_Error("rightvol out of bounds");
+
     if (leftvol < 0 || leftvol > 127)
-	I_Error("leftvol out of bounds");
-    
+  I_Error("leftvol out of bounds");
+
     // Get the proper lookup table piece
     //  for this volume level???
   channelinfo[slot].leftvol_lookup = &vol_lookup[leftvol*256];
@@ -246,12 +246,12 @@ void I_SetChannels()
 {
   // Init internal lookups (raw data, mixing buffer, channels).
   // This function sets up internal lookups used during
-  //  the mixing process. 
-  int		i;
-  int		j;
-    
-  int*	steptablemid = steptable + 128;
-  
+  //  the mixing process.
+  int   i;
+  int   j;
+
+  int*  steptablemid = steptable + 128;
+
   // Okay, reset internal mixing channels to zero.
   for (i=0; i<MAX_CHANNELS; i++)
   {
@@ -262,8 +262,8 @@ void I_SetChannels()
   // I fail to see that this is currently used.
   for (i=-128 ; i<128 ; i++)
     steptablemid[i] = (int)(pow(1.2, ((double)i/(64.0*snd_samplerate/11025)))*65536.0);
-  
-  
+
+
   // Generates volume lookup tables
   //  which also turn the unsigned samples
   //  into signed samples.
@@ -275,9 +275,9 @@ void I_SetChannels()
       vol_lookup[i*256+j] = (i*(j-128)*256)/191;
       //vol_lookup[i*256+j] = (i*(j-128)*256)/127;
     }
-}	
+}
+
 
- 
 void I_SetSfxVolume(int volume)
 {
   // Identical to DOS.
@@ -317,10 +317,10 @@ int I_StartSound(int id, int channel, int vol, int sep, int pitch, int priority)
 
   // UNUSED
   priority = 0;
-  
+
     // Debug.
     //fprintf( stderr, "starting sound %d", id );
-    
+
     SDL_LockAudio();
   // Returns a handle (not used).
   handle = addsfx(id,channel);
@@ -332,7 +332,7 @@ int I_StartSound(int id, int channel, int vol, int sep, int pitch, int priority)
     SDL_UnlockAudio();
 
     // fprintf( stderr, "/handle is %d\n", id );
-    
+
   return handle;
 }
 
@@ -377,19 +377,19 @@ void I_UpdateSound(void *unused, Uint8 *stream, int len)
   // Mix current sound data.
   // Data, from raw sound, for right and left.
   register unsigned char sample;
-  register int		dl;
-  register int		dr;
-  
+  register int    dl;
+  register int    dr;
+
   // Pointers in audio stream, left, right, end.
-  signed short*		leftout;
-  signed short*		rightout;
-  signed short*		leftend;
+  signed short*   leftout;
+  signed short*   rightout;
+  signed short*   leftend;
   // Step in stream, left and right, thus two.
-  int				step;
+  int       step;
 
   // Mixing channel index.
-  int				chan;
-   
+  int       chan;
+
     // Left and right channel
     //  are in audio stream, alternating.
     leftout = (signed short *)stream;
@@ -405,75 +405,75 @@ void I_UpdateSound(void *unused, Uint8 *stream, int len)
     //  that is 512 values for two channels.
     while (leftout != leftend)
     {
-	// Reset left/right value. 
-	//dl = 0;
-	//dr = 0;
-	dl = *leftout;
-	dr = *rightout;
+  // Reset left/right value.
+  //dl = 0;
+  //dr = 0;
+  dl = *leftout;
+  dr = *rightout;
 
-	// Love thy L2 chache - made this a loop.
-	// Now more channels could be set at compile time
-	//  as well. Thus loop those  channels.
+  // Love thy L2 chache - made this a loop.
+  // Now more channels could be set at compile time
+  //  as well. Thus loop those  channels.
     for ( chan = 0; chan < numChannels; chan++ )
-	{
-	    // Check channel, if active.
+  {
+      // Check channel, if active.
       if (channelinfo[chan].data)
-	    {
-		// Get the raw data from the channel. 
+      {
+    // Get the raw data from the channel.
         // no filtering
         // sample = *channelinfo[chan].data;
         // linear filtering
         sample = (((unsigned int)channelinfo[chan].data[0] * (0x10000 - channelinfo[chan].stepremainder))
                 + ((unsigned int)channelinfo[chan].data[1] * (channelinfo[chan].stepremainder))) >> 16;
 
-		// Add left and right part
-		//  for this channel (sound)
-		//  to the current data.
-		// Adjust volume accordingly.
+    // Add left and right part
+    //  for this channel (sound)
+    //  to the current data.
+    // Adjust volume accordingly.
         dl += channelinfo[chan].leftvol_lookup[sample];
         dr += channelinfo[chan].rightvol_lookup[sample];
-		// Increment index ???
+    // Increment index ???
         channelinfo[chan].stepremainder += channelinfo[chan].step;
-		// MSB is next sample???
+    // MSB is next sample???
         channelinfo[chan].data += channelinfo[chan].stepremainder >> 16;
-		// Limit to LSB???
+    // Limit to LSB???
         channelinfo[chan].stepremainder &= 0xffff;
 
-		// Check whether we are done.
+    // Check whether we are done.
         if (channelinfo[chan].data >= channelinfo[chan].enddata)
-		  stopchan(chan);
-	    }
-	}
-	
-	// Clamp to range. Left hardware channel.
-	// Has been char instead of short.
-	// if (dl > 127) *leftout = 127;
-	// else if (dl < -128) *leftout = -128;
-	// else *leftout = dl;
+      stopchan(chan);
+      }
+  }
 
-	if (dl > SHRT_MAX)
-	    *leftout = SHRT_MAX;
-	else if (dl < SHRT_MIN)
-	    *leftout = SHRT_MIN;
-	else
-	    *leftout = (signed short)dl;
+  // Clamp to range. Left hardware channel.
+  // Has been char instead of short.
+  // if (dl > 127) *leftout = 127;
+  // else if (dl < -128) *leftout = -128;
+  // else *leftout = dl;
 
-	// Same for right hardware channel.
-	if (dr > SHRT_MAX)
-	    *rightout = SHRT_MAX;
-	else if (dr < SHRT_MIN)
-	    *rightout = SHRT_MIN;
-	else
-	    *rightout = (signed short)dr;
+  if (dl > SHRT_MAX)
+      *leftout = SHRT_MAX;
+  else if (dl < SHRT_MIN)
+      *leftout = SHRT_MIN;
+  else
+      *leftout = (signed short)dl;
 
-	// Increment current pointers in stream
-	leftout += step;
-	rightout += step;
+  // Same for right hardware channel.
+  if (dr > SHRT_MAX)
+      *rightout = SHRT_MAX;
+  else if (dr < SHRT_MIN)
+      *rightout = SHRT_MIN;
+  else
+      *rightout = (signed short)dr;
+
+  // Increment current pointers in stream
+  leftout += step;
+  rightout += step;
     }
 }
 
 void I_ShutdownSound(void)
-{    
+{
   lprintf(LO_INFO, "I_ShutdownSound: ");
 #ifdef HAVE_MIXER
   Mix_CloseAudio();
@@ -487,7 +487,7 @@ void I_ShutdownSound(void)
 
 void
 I_InitSound()
-{ 
+{
 #ifdef HAVE_MIXER
   int audio_rate;
   Uint16 audio_format;
@@ -506,7 +506,7 @@ I_InitSound()
 #endif
   audio_channels = 2;
   audio_buffers = SAMPLECOUNT*snd_samplerate/11025;
-  
+
   if (Mix_OpenAudio(audio_rate, audio_format, audio_channels, audio_buffers) < 0) {
     lprintf(LO_INFO,"couldn't open audio with desired format\n");
     return;
@@ -519,7 +519,7 @@ I_InitSound()
 
   // Secure and configure sound device first.
   lprintf(LO_INFO,"I_InitSound: ");
-  
+
   // Open the audio device
   audio.freq = snd_samplerate;
 #if ( SDL_BYTEORDER == SDL_BIG_ENDIAN )
@@ -537,12 +537,12 @@ I_InitSound()
   SAMPLECOUNT = audio.samples;
   lprintf(LO_INFO," configured audio device with %d samples/slice\n", SAMPLECOUNT);
 #endif
-  
+
   atexit(I_ShutdownSound);
-  
+
   if (!nomusicparm)
     I_InitMusic();
-  
+
   // Finished initialization.
   lprintf(LO_INFO,"I_InitSound: sound module ready\n");
 #ifndef HAVE_MIXER
@@ -567,7 +567,7 @@ char* music_tmp; /* cph - name of music temporary file */
 
 #endif
 
-void I_ShutdownMusic(void) 
+void I_ShutdownMusic(void)
 {
 #ifdef HAVE_MIXER
   if (music_tmp) {
@@ -588,7 +588,7 @@ void I_InitMusic(void)
     if (fd<0) {
       lprintf(LO_ERROR, "I_InitMusic: failed to create music temp file %s", music_tmp);
       free(music_tmp); return;
-    } else 
+    } else
       close(fd);
   }
 #else /* !_WIN32 */
@@ -693,6 +693,31 @@ int I_RegisterSong(const void *data, size_t len)
   return (0);
 }
 
+// cournia - try to load a music file into SDL_Mixer
+//           returns true if could not load the file
+int I_RegisterMusic( const char* filename, musicinfo_t *song )
+{
+#ifdef HAVE_MIXER
+  if (!filename) return 1;
+  if (!song) return 1;
+  music[0] = Mix_LoadMUS(filename);
+  if (music[0] == NULL)
+    {
+      lprintf(LO_WARN,"Couldn't load music from %s: %s\nAttempting to load default MIDI music.\n", filename, Mix_GetError());
+      return 1;
+    }
+  else
+    {
+      song->data = 0;
+      song->handle = 0;
+      song->lumpnum = -1; //this doesn't seem to cause problems
+      return 0;
+    }
+#else
+  return 1;
+#endif
+}
+
 void I_SetMusicVolume(int volume)
 {
 #ifdef HAVE_MIXER
