@@ -1,7 +1,7 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: i_video.c,v 1.18.2.4 2001/10/07 12:34:42 proff_fs Exp $
+ * $Id: i_video.c,v 1.18.2.7 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -9,7 +9,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -22,17 +22,17 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
- *	DOOM graphics stuff for SDL
+ *  DOOM graphics stuff for SDL
  *
  *-----------------------------------------------------------------------------
  */
 
 static const char
-rcsid[] = "$Id: i_video.c,v 1.18.2.4 2001/10/07 12:34:42 proff_fs Exp $";
+rcsid[] = "$Id: i_video.c,v 1.18.2.7 2002/07/20 18:08:37 proff_fs Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "../config.h"
@@ -80,12 +80,11 @@ static SDL_Surface *screen;
 unsigned char* out_buffer = NULL;
 
 ////////////////////////////////////////////////////////////////////////////
-// Input code 
-int             leds_always_off = 0; // Expected by m_misc, not relevant 
+// Input code
+int             leds_always_off = 0; // Expected by m_misc, not relevant
 
 // Mouse handling
 extern int     usemouse;        // config file var
-static boolean grabMouse;       // internal var
 
 /////////////////////////////////////////////////////////////////////////////////
 // Keyboard handling
@@ -99,61 +98,61 @@ static int I_TranslateKey(SDL_keysym* key)
   int rc = 0;
 
   switch (key->sym) {
-  case SDLK_LEFT:	rc = KEYD_LEFTARROW;	break;
-  case SDLK_RIGHT:	rc = KEYD_RIGHTARROW;	break;
-  case SDLK_DOWN:	rc = KEYD_DOWNARROW;	break;
-  case SDLK_UP:		rc = KEYD_UPARROW;	break;
-  case SDLK_ESCAPE:	rc = KEYD_ESCAPE;	break;
-  case SDLK_RETURN:	rc = KEYD_ENTER;	break;
-  case SDLK_TAB:	rc = KEYD_TAB;		break;
-  case SDLK_F1:		rc = KEYD_F1;		break;
-  case SDLK_F2:		rc = KEYD_F2;		break;
-  case SDLK_F3:		rc = KEYD_F3;		break;
-  case SDLK_F4:		rc = KEYD_F4;		break;
-  case SDLK_F5:		rc = KEYD_F5;		break;
-  case SDLK_F6:		rc = KEYD_F6;		break;
-  case SDLK_F7:		rc = KEYD_F7;		break;
-  case SDLK_F8:		rc = KEYD_F8;		break;
-  case SDLK_F9:		rc = KEYD_F9;		break;
-  case SDLK_F10:	rc = KEYD_F10;		break;
-  case SDLK_F11:	rc = KEYD_F11;		break;
-  case SDLK_F12:	rc = KEYD_F12;		break;
-  case SDLK_BACKSPACE:	rc = KEYD_BACKSPACE;	break;
-  case SDLK_DELETE:	rc = KEYD_DEL;	break;
-  case SDLK_INSERT:	rc = KEYD_INSERT;	break;
-  case SDLK_PAGEUP:	rc = KEYD_PAGEUP;	break;
-  case SDLK_PAGEDOWN:	rc = KEYD_PAGEDOWN;	break;
-  case SDLK_HOME:	rc = KEYD_HOME;	break;
-  case SDLK_END:	rc = KEYD_END;	break;
-  case SDLK_PAUSE:	rc = KEYD_PAUSE;	break;
-  case SDLK_EQUALS:	rc = KEYD_EQUALS;	break;
-  case SDLK_MINUS:	rc = KEYD_MINUS;	break;
-  case SDLK_KP0:	rc = KEYD_KEYPAD0;	break;
-  case SDLK_KP1:	rc = KEYD_KEYPAD1;	break;
-  case SDLK_KP2:	rc = KEYD_KEYPAD2;	break;
-  case SDLK_KP3:	rc = KEYD_KEYPAD3;	break;
-  case SDLK_KP4:	rc = KEYD_KEYPAD4;	break;
-  case SDLK_KP5:	rc = KEYD_KEYPAD0;	break;
-  case SDLK_KP6:	rc = KEYD_KEYPAD6;	break;
-  case SDLK_KP7:	rc = KEYD_KEYPAD7;	break;
-  case SDLK_KP8:	rc = KEYD_KEYPAD8;	break;
-  case SDLK_KP9:	rc = KEYD_KEYPAD9;	break;
-  case SDLK_KP_PLUS:	rc = KEYD_KEYPADPLUS;	break;
-  case SDLK_KP_MINUS:	rc = KEYD_KEYPADMINUS;	break;
-  case SDLK_KP_DIVIDE:	rc = KEYD_KEYPADDIVIDE;	break;
+  case SDLK_LEFT: rc = KEYD_LEFTARROW;  break;
+  case SDLK_RIGHT:  rc = KEYD_RIGHTARROW; break;
+  case SDLK_DOWN: rc = KEYD_DOWNARROW;  break;
+  case SDLK_UP:   rc = KEYD_UPARROW;  break;
+  case SDLK_ESCAPE: rc = KEYD_ESCAPE; break;
+  case SDLK_RETURN: rc = KEYD_ENTER;  break;
+  case SDLK_TAB:  rc = KEYD_TAB;    break;
+  case SDLK_F1:   rc = KEYD_F1;   break;
+  case SDLK_F2:   rc = KEYD_F2;   break;
+  case SDLK_F3:   rc = KEYD_F3;   break;
+  case SDLK_F4:   rc = KEYD_F4;   break;
+  case SDLK_F5:   rc = KEYD_F5;   break;
+  case SDLK_F6:   rc = KEYD_F6;   break;
+  case SDLK_F7:   rc = KEYD_F7;   break;
+  case SDLK_F8:   rc = KEYD_F8;   break;
+  case SDLK_F9:   rc = KEYD_F9;   break;
+  case SDLK_F10:  rc = KEYD_F10;    break;
+  case SDLK_F11:  rc = KEYD_F11;    break;
+  case SDLK_F12:  rc = KEYD_F12;    break;
+  case SDLK_BACKSPACE:  rc = KEYD_BACKSPACE;  break;
+  case SDLK_DELETE: rc = KEYD_DEL;  break;
+  case SDLK_INSERT: rc = KEYD_INSERT; break;
+  case SDLK_PAGEUP: rc = KEYD_PAGEUP; break;
+  case SDLK_PAGEDOWN: rc = KEYD_PAGEDOWN; break;
+  case SDLK_HOME: rc = KEYD_HOME; break;
+  case SDLK_END:  rc = KEYD_END;  break;
+  case SDLK_PAUSE:  rc = KEYD_PAUSE;  break;
+  case SDLK_EQUALS: rc = KEYD_EQUALS; break;
+  case SDLK_MINUS:  rc = KEYD_MINUS;  break;
+  case SDLK_KP0:  rc = KEYD_KEYPAD0;  break;
+  case SDLK_KP1:  rc = KEYD_KEYPAD1;  break;
+  case SDLK_KP2:  rc = KEYD_KEYPAD2;  break;
+  case SDLK_KP3:  rc = KEYD_KEYPAD3;  break;
+  case SDLK_KP4:  rc = KEYD_KEYPAD4;  break;
+  case SDLK_KP5:  rc = KEYD_KEYPAD5;  break;
+  case SDLK_KP6:  rc = KEYD_KEYPAD6;  break;
+  case SDLK_KP7:  rc = KEYD_KEYPAD7;  break;
+  case SDLK_KP8:  rc = KEYD_KEYPAD8;  break;
+  case SDLK_KP9:  rc = KEYD_KEYPAD9;  break;
+  case SDLK_KP_PLUS:  rc = KEYD_KEYPADPLUS; break;
+  case SDLK_KP_MINUS: rc = KEYD_KEYPADMINUS;  break;
+  case SDLK_KP_DIVIDE:  rc = KEYD_KEYPADDIVIDE; break;
   case SDLK_KP_MULTIPLY: rc = KEYD_KEYPADMULTIPLY; break;
-  case SDLK_KP_ENTER:	rc = KEYD_KEYPADENTER;	break;
-  case SDLK_KP_PERIOD:	rc = KEYD_KEYPADPERIOD;	break;
+  case SDLK_KP_ENTER: rc = KEYD_KEYPADENTER;  break;
+  case SDLK_KP_PERIOD:  rc = KEYD_KEYPADPERIOD; break;
   case SDLK_LSHIFT:
-  case SDLK_RSHIFT:	rc = KEYD_RSHIFT;	break;
+  case SDLK_RSHIFT: rc = KEYD_RSHIFT; break;
   case SDLK_LCTRL:
-  case SDLK_RCTRL:	rc = KEYD_RCTRL;	break;
+  case SDLK_RCTRL:  rc = KEYD_RCTRL;  break;
   case SDLK_LALT:
   case SDLK_LMETA:
   case SDLK_RALT:
-  case SDLK_RMETA:	rc = KEYD_RALT;		break;
+  case SDLK_RMETA:  rc = KEYD_RALT;   break;
   case SDLK_CAPSLOCK: rc = KEYD_CAPSLOCK; break;
-  default:		rc = key->sym;		break;
+  default:    rc = key->sym;    break;
   }
 
   return rc;
@@ -214,57 +213,13 @@ static void I_GetEvent(SDL_Event *Event)
   break;
 
   case SDL_MOUSEMOTION:
-#ifndef POLL_MOUSE
-  /* Ignore mouse warp events */
-  if (usemouse &&
-      ((Event->motion.x != screen->w/2)||(Event->motion.y != screen->h/2)))
-  {
-    /* Warp the mouse back to the center */
-    if (grabMouse && !(paused || (gamestate != GS_LEVEL) || demoplayback)) {
-      if ( (Event->motion.x < ((screen->w/2)-(screen->w/4))) ||
-           (Event->motion.x > ((screen->w/2)+(screen->w/4))) ||
-           (Event->motion.y < ((screen->h/2)-(screen->h/4))) ||
-           (Event->motion.y > ((screen->h/2)+(screen->h/4))) )
-        SDL_WarpMouse((Uint16)(screen->w/2), (Uint16)(screen->h/2));
-    }
+  if (usemouse) {
     event.type = ev_mouse;
     event.data1 = I_SDLtoDoomMouseState(Event->motion.state);
     event.data2 = Event->motion.xrel << 5;
     event.data3 = -Event->motion.yrel << 5;
     D_PostEvent(&event);
   }
-#else
-  /* cph - under X11 fullscreen, SDL's MOUSEMOTION events are just too
-   *  unreliable. Deja vu, I had similar trouble in the early LxDoom days
-   *  with X11 mouse motion events. Except SDL makes it worse, because
-   *  it feeds SDL_WarpMouse events back to us. */
-  if (usemouse) {
-    static int px,py;
-    static int was_grabbed;
-    int x,y,dx,dy;
-    Uint8 buttonstate = SDL_GetMouseState(&x,&y);
-    if (was_grabbed) { /* Previous position saved */
-      dx = x - px; dy = y - py;
-      if (!(dx | dy)) break; /* No motion, not interesting */
-      event.type = ev_mouse;
-      event.data1 = I_SDLtoDoomMouseState(buttonstate);
-      event.data2 = dx << 5; event.data3 = -dy << 5;
-      D_PostEvent(&event);
-    }
-    /* Warp the mouse back to the center */
-    was_grabbed = 0;
-    if (grabMouse && !(paused || (gamestate != GS_LEVEL) || demoplayback)) {
-      if ( (x < (screen->w/4)) ||
-           (x > (3*screen->w/4)) ||
-           (y < (screen->h/4)) ||
-           (y > (3*screen->h/4)) ) {
-        SDL_WarpMouse((Uint16)(screen->w/2), (Uint16)(screen->h/2));
-      } else {
-        px = x; py = y; was_grabbed = 1;
-      }
-    }
-  }
-#endif
   break;
 
 
@@ -281,13 +236,23 @@ static void I_GetEvent(SDL_Event *Event)
 //
 // I_StartTic
 //
+static int mouse_currently_grabbed;
+
 void I_StartTic (void)
 {
   SDL_Event Event;
+  {
+    int should_be_grabbed = usemouse &&
+      !(paused || (gamestate != GS_LEVEL) || demoplayback);
+
+    if (mouse_currently_grabbed != should_be_grabbed)
+      SDL_WM_GrabInput((mouse_currently_grabbed = should_be_grabbed)
+          ? SDL_GRAB_ON : SDL_GRAB_OFF);
+  }
 
   while ( SDL_PollEvent(&Event) )
     I_GetEvent(&Event);
-  
+
   I_PollJoystick();
 }
 
@@ -304,10 +269,6 @@ void I_StartFrame (void)
 
 static void I_InitInputs(void)
 {
-  // check if the user wants to grab the mouse (quite unnice)
-  grabMouse = M_CheckParm("-nomouse") ? false : 
-    usemouse ? true : false;
-
   I_InitJoystick();
 }
 /////////////////////////////////////////////////////////////////////////////
@@ -339,7 +300,7 @@ static void I_UploadNewPalette(int pal)
   // This is used to replace the current 256 colour cmap with a new one
   // Used by 256 colour PseudoColor modes
 
-  // Array of SDL_Color structs used for setting the 256-colour palette 
+  // Array of SDL_Color structs used for setting the 256-colour palette
   static SDL_Color* colours;
   static int cachedgamma;
   static size_t num_pals;
@@ -368,17 +329,17 @@ static void I_UploadNewPalette(int pal)
       colours[i].b = gtable[palette[2]];
       palette += 3;
     }
-  
+
     W_UnlockLumpNum(lump);
     num_pals/=256;
   }
 
 #ifdef RANGECHECK
-  if ((size_t)pal >= num_pals) 
-    I_Error("I_UploadNewPalette: Palette number out of range (%d>=%d)", 
-	    pal, num_pals);
+  if ((size_t)pal >= num_pals)
+    I_Error("I_UploadNewPalette: Palette number out of range (%d>=%d)",
+      pal, num_pals);
 #endif
-  
+
   // store the colors to the current display
   SDL_SetColors(SDL_GetVideoSurface(), colours+256*pal, 0, 256);
 }
@@ -412,7 +373,7 @@ void I_FinishUpdate (void)
     return;
   }
 #endif
-  
+
 #ifndef GL_DOOM
   if (screen->pixels != screens[0])
   {
@@ -423,26 +384,24 @@ void I_FinishUpdate (void)
       char *src;
       char *dest;
 
-      if (SDL_LockSurface(screen) >= 0)
+      if (SDL_LockSurface(screen) < 0)
+        I_Error("I_FinishUpdate: Couldn't lock screen surface");
+      dest=(char *)screen->pixels;
+      src=screens[0];
+      w=screen->w;
+      h=screen->h;
+      for (; h>0; h--)
       {
-        //dest=(char *)(screen->pixels)+(screen->clip_rect.y*screen->pitch)+screen->clip_rect.x;
-        dest=(char *)screen->pixels;
-        src=screens[0];
-        w=(screen->clip_rect.w>SCREENWIDTH)?(SCREENWIDTH):(screen->clip_rect.w);
-        h=(screen->clip_rect.h>SCREENHEIGHT)?(SCREENHEIGHT):(screen->clip_rect.h);
-        for (; h>0; h--)
-        {
-          memcpy(dest,src,w);
-          dest+=screen->pitch;
-          src+=SCREENWIDTH;
-        }
-        SDL_UnlockSurface(screen);
+        memcpy(dest,src,w);
+        dest+=screen->pitch;
+        src+=SCREENWIDTH;
       }
+      SDL_UnlockSurface(screen);
     }
   }
   /* Update the display buffer (flipping video pages if supported)
    * If we need to change palette, that implicitely does a flip */
-  if (newpal != NO_PALETTE_CHANGE) { 
+  if (newpal != NO_PALETTE_CHANGE) {
     I_UploadNewPalette(newpal);
     newpal = NO_PALETTE_CHANGE;
   } else
@@ -473,8 +432,8 @@ void I_SetPalette (int pal)
 
 void I_ShutdownSDL(void)
 {
-	SDL_Quit();
-	return;
+  SDL_Quit();
+  return;
 }
 
 void I_PreInitGraphics(void)
@@ -483,7 +442,7 @@ void I_PreInitGraphics(void)
   if ( SDL_Init(SDL_INIT_VIDEO) < 0 ) {
     I_Error("Could not initialize SDL [%s]", SDL_GetError());
   }
-  
+
   atexit(I_ShutdownSDL);
 }
 
@@ -502,12 +461,12 @@ void I_SetRes(unsigned int width, unsigned int height)
 void I_InitGraphics(void)
 {
   char titlebuffer[2048];
-  static int		firsttime=1;
-  
+  static int    firsttime=1;
+
   if (firsttime)
-  {  
+  {
     firsttime = 0;
-    
+
     atexit(I_ShutdownGraphics);
     lprintf(LO_INFO, "I_InitGraphics: %dx%d\n", SCREENWIDTH, SCREENHEIGHT);
 
@@ -536,7 +495,7 @@ void I_UpdateVideoMode(void)
 
   w = SCREENWIDTH;
   h = SCREENHEIGHT;
-  
+
   // Initialize SDL with this graphics mode
 #ifdef GL_DOOM
   init_flags = SDL_OPENGL;
@@ -574,7 +533,7 @@ void I_UpdateVideoMode(void)
     I_Error("Couldn't set %dx%d video mode [%s]", w, h, SDL_GetError());
   }
 
-  //mouse_currently_grabbed = false;
+  mouse_currently_grabbed = false;
 
   // Get the info needed to render to the display
   if (screen->pixels != NULL)
@@ -582,7 +541,7 @@ void I_UpdateVideoMode(void)
     if (out_buffer)
       free(out_buffer);
     out_buffer=NULL;
-    screens[0] = (unsigned char *) (screen->pixels); 
+    screens[0] = (unsigned char *) (screen->pixels);
   }
   else
   {
