@@ -1,7 +1,7 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: d_main.c,v 1.32.2.2 2001/10/07 12:34:42 proff_fs Exp $
+ * $Id: d_main.c,v 1.32.2.5 2002/07/21 10:19:55 cph Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -9,7 +9,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -22,7 +22,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -34,7 +34,7 @@
  *-----------------------------------------------------------------------------
  */
 
-static const char rcsid[] = "$Id: d_main.c,v 1.32.2.2 2001/10/07 12:34:42 proff_fs Exp $";
+static const char rcsid[] = "$Id: d_main.c,v 1.32.2.5 2002/07/21 10:19:55 cph Exp $";
 
 #ifdef _MSC_VER
 #define    F_OK    0    /* Check for file existence */
@@ -165,7 +165,7 @@ void D_PostEvent(event_t *ev)
 {
   /* cph - suppress all input events at game start
    * FIXME: This is a lousy kludge */
-  if (gametic < 3) return; 
+  if (gametic < 3) return;
   events[eventhead++] = *ev;
   eventhead &= MAXEVENTS-1;
 }
@@ -202,7 +202,7 @@ static void D_Wipe(void)
       int nowtime, tics;
       do
         {
-	        I_uSleep(5000); // CPhipps - don't thrash cpu in this loop
+          I_uSleep(5000); // CPhipps - don't thrash cpu in this loop
           nowtime = I_GetTime();
           tics = nowtime - wipestart;
         }
@@ -251,7 +251,7 @@ void D_Display (void)
     switch (oldgamestate) {
     case -1:
     case GS_LEVEL:
-      V_SetPalette(0); // cph - use default (basic) palette  
+      V_SetPalette(0); // cph - use default (basic) palette
     default:
       break;
     }
@@ -281,17 +281,17 @@ void D_Display (void)
 
     // Work out if the player view is visible, and if there is a border
     viewactive = (!(automapmode & am_active) || (automapmode & am_overlay)) && !inhelpscreens;
-    isborder = viewactive ? (viewheight != SCREENHEIGHT) : (!inhelpscreens && (automapmode & am_active)); 
+    isborder = viewactive ? (viewheight != SCREENHEIGHT) : (!inhelpscreens && (automapmode & am_active));
 
     if (oldgamestate != GS_LEVEL) {
       R_FillBackScreen ();    // draw the pattern into the back screen
       redrawborderstuff = isborder;
     } else {
-      // CPhipps - 
-      // If there is a border, and either there was no border last time, 
+      // CPhipps -
+      // If there is a border, and either there was no border last time,
       // or the border might need refreshing, then redraw it.
       redrawborderstuff = isborder && (!isborderstate || borderwillneedredraw);
-      // The border may need redrawing next time if the border surrounds the screen, 
+      // The border may need redrawing next time if the border surrounds the screen,
       // and there is a menu being displayed
       borderwillneedredraw = menuactive && isborder && viewactive && (viewwidth != SCREENWIDTH);
     }
@@ -323,16 +323,16 @@ void D_Display (void)
       static int x;
 
       if (!x) { // Cache results of x pos calc
-	int lump = W_GetNumForName("M_PAUSE");
-	const patch_t* p = W_CacheLumpNum(lump);
-	x = (320 - SHORT(p->width))/2;
-	W_UnlockLumpNum(lump);
+  int lump = W_GetNumForName("M_PAUSE");
+  const patch_t* p = W_CacheLumpNum(lump);
+  x = (320 - SHORT(p->width))/2;
+  W_UnlockLumpNum(lump);
       }
 
       // CPhipps - updated for new patch drawing
-      V_DrawNamePatch(x, (!(automapmode & am_active) || (automapmode & am_overlay)) 
-		      ? 4+(viewwindowy*200/SCREENHEIGHT) : 4, // cph - Must un-stretch viewwindowy
-		      0, "M_PAUSE", CR_DEFAULT, VPT_STRETCH);
+      V_DrawNamePatch(x, (!(automapmode & am_active) || (automapmode & am_overlay))
+          ? 4+(viewwindowy*200/SCREENHEIGHT) : 4, // cph - Must un-stretch viewwindowy
+          0, "M_PAUSE", CR_DEFAULT, VPT_STRETCH);
   }
 
   // menus go directly to the screen
@@ -342,7 +342,7 @@ void D_Display (void)
 #else
   D_BuildNewTiccmds();
 #endif
-  
+
 #ifndef GL_DOOM
   // normal update
   if (!wipe)
@@ -379,7 +379,7 @@ static void D_DoomLoop(void)
 {
   basetic = gametic;
 
-#ifdef HAVE_NET 
+#ifdef HAVE_NET
   atexit(D_QuitNetGame);       // killough
 #endif
 
@@ -412,8 +412,8 @@ static void D_DoomLoop(void)
 
       // CPhipps - auto screenshot
       if (auto_shot_fname && !--auto_shot_count) {
-	auto_shot_count = auto_shot_time;
-	M_DoScreenShot(auto_shot_fname);
+  auto_shot_count = auto_shot_time;
+  M_DoScreenShot(auto_shot_fname);
       }
     }
 }
@@ -461,7 +461,7 @@ void D_AdvanceDemo (void)
   advancedemo = true;
 }
 
-/* killough 11/98: functions to perform demo sequences 
+/* killough 11/98: functions to perform demo sequences
  * cphipps 10/99: constness fixes
  */
 
@@ -483,10 +483,10 @@ static void D_DrawTitle2(const char *name)
   D_SetPageName(name);
 }
 
-/* killough 11/98: tabulate demo sequences 
+/* killough 11/98: tabulate demo sequences
  */
 
-static struct 
+static struct
 {
   void (*func)(const char *);
   const char *name;
@@ -606,55 +606,6 @@ void D_AddFile (const char *file, wad_source_t source)
   numwadfiles++;
 }
 
-// Return the path where the executable lies -- Lee Killough
-#ifdef _WIN32
-char *D_DoomExeDir(void)
-{
-  static const char current_dir_dummy[] = {"./"};
-  static char *base;
-  if (!base)        // cache multiple requests
-    {
-      size_t len = strlen(*myargv);
-      char *p = (base = malloc(len+1)) + len - 1;
-      strcpy(base,*myargv);
-      while (p > base && *p!='/' && *p!='\\')
-        *p--=0;
-      if (*p=='/' || *p=='\\')
-        *p--=0;
-      if (strlen(base)<2)
-      {
-        free(base);
-        base = malloc(1024);
-        if (!getcwd(base,1024))
-          strcpy(base, current_dir_dummy);
-      }
-    }
-  return base;
-}
-#else
-// cph - V.Aguilar (5/30/99) suggested return ~/.lxdoom/, creating
-//  if non-existant
-static const char prboom_dir[] = {"/.prboom/"};
-
-char *D_DoomExeDir(void)
-{
-  static char *base;
-  if (!base)        // cache multiple requests
-    {
-      char *home = getenv("HOME");
-      size_t len = strlen(home);
-
-      base = malloc(len + strlen(prboom_dir) + 1);
-      strcpy(base, home);
-      // I've had trouble with trailing slashes before...
-      if (base[len-1] == '/') base[len-1] = 0;
-      strcat(base, prboom_dir);
-      mkdir(base, S_IRUSR | S_IWUSR | S_IXUSR); // Make sure it exists
-    }
-  return base;
-}
-#endif
-
 // killough 10/98: support -dehout filename
 // cph - made const, don't cache results
 static const char *D_dehout(void)
@@ -788,17 +739,6 @@ void NormalizeSlashes(char *str)
       str[l]='/';
 }
 
-/* 
- * HasTrailingSlash
- *
- * cphipps - simple test for trailing slash on dir names
- */
-
-static boolean HasTrailingSlash(const char* dn)
-{
-  return (dn[strlen(dn)-1] == '/');
-}
-
 // jff 4/19/98 Add routine to check a pathname for existence as
 // a file or directory. If neither append .wad and check if it
 // exists as a file then. Else return non-existent.
@@ -834,94 +774,24 @@ boolean WadFileStatus(char *filename,boolean *isdir)
   return false;                   //and report doesn't exist
 }
 
-/* 
- * FindWADFile
- *
- * cphipps 19/1999 - writen to unify the logic in FindIWADFile and the WAD 
- * 			autoloading code.
- * Searches the standard dirs for a named WAD file
- * The dirs are: 
- * . 
- * DOOMWADDIR 
- * ~/doom 
- * /usr/share/games/doom 
- * /usr/local/share/games/doom
- * ~
- */
-
-static char* FindWADFile(const char* wfname, const char* ext)
-{
-  int		i;
-  /* Precalculate a length we will need in the loop */
-  size_t	pl = strlen(wfname) + strlen(ext) + 4;
-
-  for (i=0; i<8; i++) {
-    char	*	p;
-    const char	*	d = NULL;
-    const char	*	s = NULL;
-    /* Each entry in the switch sets d to the directory to look in, 
-     * and optionally s to a subdirectory of d */
-    switch(i) {
-    case 1:
-      if (!(d = getenv("DOOMWADDIR"))) continue;
-    case 0:
-      break;
-    case 2:
-      d = DOOMWADDIR;
-      break;
-    case 4:
-      d = "/usr/share/games/doom";
-      break;
-    case 5:
-      d = "/usr/local/share/games/doom";
-      break;
-    case 6:
-      d = D_DoomExeDir();
-    case 3:
-      s = "doom";
-    case 7:
-      if (!(d = getenv("HOME"))) continue;
-      break;
-#ifdef SIMPLECHECKS
-    default:
-      I_Error("FindWADFile: Internal failure");
-#endif
-    }
-
-    p = malloc((d ? strlen(d) : 0) + (s ? strlen(s) : 0) + pl);
-    sprintf(p, "%s%s%s%s%s", d ? d : "", (d && !HasTrailingSlash(d)) ? "/" : "",
-                             s ? s : "", (s && !HasTrailingSlash(s)) ? "/" : "",
-                             wfname);
-
-    if (access(p,F_OK))
-      strcat(p, ext);
-    if (!access(p,F_OK)) {
-      lprintf(LO_INFO, " found %s\n", p);
-      return p;
-    }
-    free(p);
-  }
-  return NULL;
-}
-
 /*
  * FindIWADFIle
  *
  * Search for one of the standard IWADs
- * CPhipps	- static, proper prototype
- *		- 12/1999 - rewritten to use FindWADFile
+ * CPhipps  - static, proper prototype
+ *    - 12/1999 - rewritten to use FindWADFile
  */
 static char *FindIWADFile(void)
 {
-  int		i;
-  char	*	iwad	= NULL;
+  int   i;
+  char  * iwad  = NULL;
 
   i = M_CheckParm("-iwad");
   if (i && (++i < myargc)) {
-    iwad =FindWADFile(myargv[i], ".wad");
+    iwad = I_FindFile(myargv[i], ".wad");
   } else {
     for (i=0; !iwad && i<nstandard_iwads; i++)
-      iwad = FindWADFile(standard_iwads[i], ".wad");
+      iwad = I_FindFile(standard_iwads[i], ".wad");
   }
   return iwad;
 }
@@ -932,7 +802,7 @@ static char *FindIWADFile(void)
 // Set the location of the defaults file and the savegame root
 // Locate and validate an IWAD file
 // Determine gamemode from the IWAD
-// 
+//
 // supports IWADs with custom names. Also allows the -iwad parameter to
 // specify which iwad is being searched for if several exist in one dir.
 // The -iwad parm may specify:
@@ -955,9 +825,9 @@ void IdentifyVersion (void)
 
   // get config file from same directory as executable
 #ifdef GL_DOOM
-  sprintf(basedefault,"%s/glboom.cfg", D_DoomExeDir());  // killough
+  sprintf(basedefault,"%s/glboom.cfg", I_DoomExeDir());  // killough
 #else
-  sprintf(basedefault,"%s/prboom.cfg", D_DoomExeDir());  // killough
+  sprintf(basedefault,"%s/prboom.cfg", I_DoomExeDir());  // killough
 #endif
 
   // set save path to -save parm or current dir
@@ -968,10 +838,10 @@ void IdentifyVersion (void)
     // CPhipps - use DOOMSAVEDIR if defined
     char* p = getenv("DOOMSAVEDIR");
 
-    if (p != NULL) 
+    if (p != NULL)
       if (strlen(p) > PATH_MAX-12) p = NULL;
 
-    strcpy(basesavegame,(p == NULL) ? D_DoomExeDir() : p);
+    strcpy(basesavegame,(p == NULL) ? I_DoomExeDir() : p);
   }
   if ((i=M_CheckParm("-save")) && i<myargc-1) //jff 3/24/98 if -save present
   {
@@ -1008,7 +878,7 @@ void IdentifyVersion (void)
     CheckIWAD(iwad,&gamemode,&haswolflevels);
 
     /* jff 8/23/98 set gamemission global appropriately in all cases
-     * cphipps 12/1999 - no version output here, leave that to the caller 
+     * cphipps 12/1999 - no version output here, leave that to the caller
      */
     switch(gamemode)
     {
@@ -1079,7 +949,7 @@ void FindResponseFile (void)
         // proff 04/05/2000: Added for searching responsefile
         if (!handle)
         {
-          strcat(strcpy(fname,D_DoomExeDir()),&myargv[i][1]);
+          strcat(strcpy(fname,I_DoomExeDir()),&myargv[i][1]);
           AddDefaultExtension(fname,".rsp");
           handle = fopen (fname,"rb");
         }
@@ -1087,8 +957,8 @@ void FindResponseFile (void)
         {
             /* proff 04/05/2000: Changed from LO_FATAL
              * proff 04/05/2000: Simply removed the exit(1);
-	     * cph - made fatal, don't drop through and SEGV
-	     */
+       * cph - made fatal, don't drop through and SEGV
+       */
             I_Error("No such response file: %s",fname);
         }
         //jff 9/3/98 use logical output routine
@@ -1100,11 +970,11 @@ void FindResponseFile (void)
         {
           lprintf(LO_ERROR,"\nResponse file empty!\n");
           fclose(handle);
-	        {
-	          const char *firstargv = myargv[0];
-	          newargv = calloc(sizeof(char *),MAXARGVS);
-	          newargv[0] = firstargv;
-  	      }
+          {
+            const char *firstargv = myargv[0];
+            newargv = calloc(sizeof(char *),MAXARGVS);
+            newargv[0] = firstargv;
+          }
           for (k = 1,index = 1;k < myargc;k++)
           {
             if (i!=k)
@@ -1122,11 +992,11 @@ void FindResponseFile (void)
         for (index = 0,k = i+1; k < myargc; k++)
           moreargs[index++] = myargv[k];
 
-	      {
-	        const char *firstargv = myargv[0];
-	        newargv = calloc(sizeof(char *),MAXARGVS);
-	        newargv[0] = firstargv;
-	      }
+        {
+          const char *firstargv = myargv[0];
+          newargv = calloc(sizeof(char *),MAXARGVS);
+          newargv[0] = firstargv;
+        }
 
         infile = file;
         indexinfile = k = 0;
@@ -1168,11 +1038,11 @@ void FindResponseFile (void)
 // work, so we have to go get all the valid ones if any that show up
 // after the loose ones.  This means that boom fred.wad -file wilma
 // will still load fred.wad and wilma.wad, in that order.
-// The response file code kludges up its own version of myargv[] and 
+// The response file code kludges up its own version of myargv[] and
 // unfortunately we have to do the same here because that kludge only
 // happens if there _is_ a response file.  Truth is, it's more likely
-// that there will be a need to do one or the other so it probably 
-// isn't important.  We'll point off to the original argv[], or the 
+// that there will be a need to do one or the other so it probably
+// isn't important.  We'll point off to the original argv[], or the
 // area allocated in FindResponseFile, or our own areas from strdups.
 //
 // CPhipps - OUCH! Writing into *myargv is too dodgy, damn
@@ -1195,17 +1065,17 @@ void DoLooseFiles(void)
 
   for (i=1;i<myargc;i++)
   {
-    if (*myargv[i] == '-') break;  // quit at first switch 
+    if (*myargv[i] == '-') break;  // quit at first switch
 
     // so now we must have a loose file.  Find out what kind and store it.
     j = strlen(myargv[i]);
-    if (!stricmp(&myargv[i][j-4],".wad")) 
+    if (!stricmp(&myargv[i][j-4],".wad"))
       wads[wadcount++] = strdup(myargv[i]);
-    if (!stricmp(&myargv[i][j-4],".lmp")) 
+    if (!stricmp(&myargv[i][j-4],".lmp"))
       lmps[lmpcount++] = strdup(myargv[i]);
-    if (!stricmp(&myargv[i][j-4],".deh")) 
+    if (!stricmp(&myargv[i][j-4],".deh"))
       dehs[dehcount++] = strdup(myargv[i]);
-    if (!stricmp(&myargv[i][j-4],".bex")) 
+    if (!stricmp(&myargv[i][j-4],".bex"))
       dehs[dehcount++] = strdup(myargv[i]);
     if (myargv[i][j-4] != '.')  // assume wad if no extension
       wads[wadcount++] = strdup(myargv[i]);
@@ -1248,7 +1118,7 @@ void DoLooseFiles(void)
   // Now go back and redo the whole myargv array with our stuff in it.
   // First, create a new myargv array to copy into
   tmyargv = calloc(sizeof(char *),MAXARGVS);
-  tmyargv[0] = myargv[0]; // invocation 
+  tmyargv[0] = myargv[0]; // invocation
   tmyargc = 1;
 
   // put our stuff into it
@@ -1262,17 +1132,17 @@ void DoLooseFiles(void)
   // for -deh
   if (dehcount > 0)
   {
-    tmyargv[tmyargc++] = strdup("-deh"); 
+    tmyargv[tmyargc++] = strdup("-deh");
     for (i=0;i<dehcount;)
-      tmyargv[tmyargc++] = dehs[i++]; 
+      tmyargv[tmyargc++] = dehs[i++];
   }
 
   // for -playdemo
   if (lmpcount > 0)
   {
-    tmyargv[tmyargc++] = strdup("-playdemo"); 
+    tmyargv[tmyargc++] = strdup("-playdemo");
     for (i=0;i<lmpcount;)
-      tmyargv[tmyargc++] = lmps[i++]; 
+      tmyargv[tmyargc++] = lmps[i++];
   }
 
   // then copy everything that's there now
@@ -1295,7 +1165,7 @@ unsigned int desired_screenwidth, desired_screenheight;
 //
 // D_DoomMainSetup
 //
-// CPhipps - the old contents of D_DoomMain, but moved out of the main 
+// CPhipps - the old contents of D_DoomMain, but moved out of the main
 //  line of execution so its stack space can be freed
 
 void D_DoomMainSetup(void)
@@ -1304,13 +1174,11 @@ void D_DoomMainSetup(void)
   const char *cena="ICWEFDA",*pos;  //jff 9/3/98 use this for parsing console masks // CPhipps - const char*'s
 
   // figgi 09/18/00-- added switch to force classic bsp nodes
-#ifdef GL_DOOM
   if (M_CheckParm ("-forceoldbsp"))
   {
-	  extern boolean forceOldBsp;
-	  forceOldBsp = true;
+    extern boolean forceOldBsp;
+    forceOldBsp = true;
   }
-#endif
 
   //jff 9/3/98 get mask for console output filter
   if ((p = M_CheckParm ("-cout")))
@@ -1407,7 +1275,7 @@ void D_DoomMainSetup(void)
       switch (gamemission)
       {
         case pack_plut:
-	  doomverstr = "DOOM 2: Plutonia Experiment";
+    doomverstr = "DOOM 2: Plutonia Experiment";
           break;
         case pack_tnt:
           doomverstr = "DOOM 2: TNT - Evilution";
@@ -1424,10 +1292,10 @@ void D_DoomMainSetup(void)
 
     /* cphipps - the main display. This shows the build date, copyright, and game type */
     lprintf(LO_ALWAYS,"PrBoom (built %s), playing: %s\n"
-	    "PrBoom is released under the GNU General Public license v2.0.\n"
-	    "You are welcome to redistribute it under certain conditions.\n"
-	    "It comes with ABSOLUTELY NO WARRANTY. See the file COPYING for details.\n",
-	    version_date, doomverstr);
+      "PrBoom is released under the GNU General Public license v2.0.\n"
+      "You are welcome to redistribute it under certain conditions.\n"
+      "It comes with ABSOLUTELY NO WARRANTY. See the file COPYING for details.\n",
+      version_date, doomverstr);
   }
 
   if (devparm)
@@ -1489,14 +1357,14 @@ void D_DoomMainSetup(void)
     lprintf(LO_CONFIRM,"Austin Virtual Gaming: Levels will end after 20 minutes\n");
 
   if ((p = M_CheckParm ("-warp")) ||      // killough 5/2/98
-       (p = M_CheckParm ("-wart"))) 
+       (p = M_CheckParm ("-wart")))
        // Ty 08/29/98 - moved this check later so we can have -warp alone: && p < myargc-1)
   {
     startmap = 0; // Ty 08/29/98 - allow "-warp x" to go to first map in wad(s)
     autostart = true; // Ty 08/29/98 - move outside the decision tree
     if (gamemode == commercial)
     {
-      if (p < myargc-1) 
+      if (p < myargc-1)
         startmap = atoi(myargv[p+1]);   // Ty 08/29/98 - add test if last parm
     }
     else    // 1/25/98 killough: fix -warp xxx from crashing Doom 1 / UD
@@ -1548,11 +1416,11 @@ void D_DoomMainSetup(void)
   // jff 3/24/98 this sets startskill if it was -1
 
   // Video stuff
-  if ((p = M_CheckParm("-width"))) 
+  if ((p = M_CheckParm("-width")))
     if (myargv[p+1])
       desired_screenwidth = atoi(myargv[p+1]);
-  
-  if ((p = M_CheckParm("-height"))) 
+
+  if ((p = M_CheckParm("-height")))
     if (myargv[p+1])
       desired_screenheight = atoi(myargv[p+1]);
 
@@ -1567,28 +1435,28 @@ void D_DoomMainSetup(void)
     // and bad parameters
     if (p && (p+1<myargc))
       if (strlen(myargv[p+1]) < 19) {
-	char* ph;
-	strcpy(buf, myargv[p+1]);
-	if ((ph = strchr(buf, 'x'))) {
-	  *ph++ = 0;
-	  if (strchr(ph, '-')) *strchr(ph, '-') = 0;
-	  if (strchr(ph, '+')) *strchr(ph, '+') = 0;
-	  w = atoi(buf); h = atoi(ph);
-	}
+  char* ph;
+  strcpy(buf, myargv[p+1]);
+  if ((ph = strchr(buf, 'x'))) {
+    *ph++ = 0;
+    if (strchr(ph, '-')) *strchr(ph, '-') = 0;
+    if (strchr(ph, '+')) *strchr(ph, '+') = 0;
+    w = atoi(buf); h = atoi(ph);
+  }
       }
 
     I_SetRes(w, h);
   }
 
-  if ((p = M_CheckParm("-fullscreen"))) 
+  if ((p = M_CheckParm("-fullscreen")))
       use_fullscreen = 1;
 
-  if ((p = M_CheckParm("-nofullscreen"))) 
+  if ((p = M_CheckParm("-nofullscreen")))
       use_fullscreen = 0;
 
 #ifdef GL_DOOM
   // proff 04/05/2000: for GL-specific switches
- 	gld_InitCommandLine();
+  gld_InitCommandLine();
 #endif
 
   //jff 9/3/98 use logical output routine
@@ -1603,22 +1471,22 @@ void D_DoomMainSetup(void)
     int i;
 
     for (i=0; i<MAXLOADFILES*2; i++) {
-      const char *fname = (i < MAXLOADFILES) ? wad_files[i] 
-	: deh_files[i - MAXLOADFILES];
+      const char *fname = (i < MAXLOADFILES) ? wad_files[i]
+  : deh_files[i - MAXLOADFILES];
       char *fpath;
 
       if (!(fname && *fname)) continue;
       // Filename is now stored as a zero terminated string
-      fpath = FindWADFile(fname, (i < MAXLOADFILES) ? ".wad" : ".bex");
+      fpath = I_FindFile(fname, (i < MAXLOADFILES) ? ".wad" : ".bex");
       if (!fpath)
         lprintf(LO_WARN, "Failed to autoload %s\n", fname);
       else {
-        if (i >= MAXLOADFILES) 
+        if (i >= MAXLOADFILES)
           ProcessDehFile(fpath, D_dehout(), 0);
         else {
           D_AddFile(fpath,source_auto_load);
         }
-        modifiedgame = true; 
+        modifiedgame = true;
         free(fpath);
       }
     }
@@ -1726,7 +1594,7 @@ void D_DoomMainSetup(void)
   idmusnum = -1; //jff 3/17/98 insure idmus number is blank
 
   // CPhipps - auto screenshots
-  if ((p = M_CheckParm("-autoshot")) && (p < myargc-2)) 
+  if ((p = M_CheckParm("-autoshot")) && (p < myargc-2))
     if ((auto_shot_count = auto_shot_time = atoi(myargv[p+1])))
       auto_shot_fname = myargv[p+2];
 
@@ -1746,7 +1614,7 @@ void D_DoomMainSetup(void)
 
   // start the apropriate game based on parms
 
-  // killough 12/98: 
+  // killough 12/98:
   // Support -loadgame with -record and reimplement -recordfrom.
 
   if ((slot = M_CheckParm("-recordfrom")) && (p = slot+2) < myargc)
@@ -1755,10 +1623,10 @@ void D_DoomMainSetup(void)
     {
       slot = M_CheckParm("-loadgame");
       if ((p = M_CheckParm("-record")) && ++p < myargc)
-	{
-	  autostart = true;
-	  G_RecordDemo(myargv[p]);
-	}
+  {
+    autostart = true;
+    G_RecordDemo(myargv[p]);
+  }
     }
 
   if ((p = M_CheckParm ("-fastdemo")) && ++p < myargc)
@@ -1771,17 +1639,17 @@ void D_DoomMainSetup(void)
   else
     if ((p = M_CheckParm("-timedemo")) && ++p < myargc)
       {
-	singletics = true;
-	timingdemo = true;            // show stats after quit
-	G_DeferedPlayDemo(myargv[p]);
-	singledemo = true;            // quit after one demo
+  singletics = true;
+  timingdemo = true;            // show stats after quit
+  G_DeferedPlayDemo(myargv[p]);
+  singledemo = true;            // quit after one demo
       }
     else
       if ((p = M_CheckParm("-playdemo")) && ++p < myargc)
-	{
-	  G_DeferedPlayDemo(myargv[p]);
-	  singledemo = true;          // quit after one demo
-	}
+  {
+    G_DeferedPlayDemo(myargv[p]);
+    singledemo = true;          // quit after one demo
+  }
 
   if (slot && ++slot < myargc)
     {
@@ -1791,13 +1659,13 @@ void D_DoomMainSetup(void)
   else
     if (!singledemo) {                  /* killough 12/98 */
       if (autostart || netgame)
-	{
-	  G_InitNew(startskill, startepisode, startmap);
-	  if (demorecording)
-	    G_BeginRecording();
-	}
+  {
+    G_InitNew(startskill, startepisode, startmap);
+    if (demorecording)
+      G_BeginRecording();
+  }
       else
-	D_StartTitle();                 // start up intro loop
+  D_StartTitle();                 // start up intro loop
     }
 }
 
@@ -1816,7 +1684,7 @@ void D_DoomMain(void)
 // GetFirstMap
 //
 // Ty 08/29/98 - determine first available map from the loaded wads and run it
-// 
+//
 
 void GetFirstMap(int *ep, int *map)
 {
@@ -1882,7 +1750,7 @@ void GetFirstMap(int *ep, int *map)
           }
         }
       }
-    }   
+    }
     //jff 9/3/98 use logical output routine
     lprintf(LO_CONFIRM,"Auto-warping to first %slevel: %s\n",
       newlevel ? "new " : "", name);  // Ty 10/04/98 - new level test
