@@ -1,7 +1,7 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: p_tick.c,v 1.7 2000/09/16 20:20:42 proff_fs Exp $
+ * $Id: p_tick.c,v 1.7.2.1 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -9,7 +9,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -22,7 +22,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -31,7 +31,7 @@
  *-----------------------------------------------------------------------------*/
 
 static const char
-rcsid[] = "$Id: p_tick.c,v 1.7 2000/09/16 20:20:42 proff_fs Exp $";
+rcsid[] = "$Id: p_tick.c,v 1.7.2.1 2002/07/20 18:08:37 proff_fs Exp $";
 
 #include "doomstat.h"
 #include "p_user.h"
@@ -52,7 +52,7 @@ int leveltime;
 thinker_t thinkercap;
 
 // killough 8/29/98: we maintain several separate threads, each containing
-// a special class of thinkers, to allow more efficient searches. 
+// a special class of thinkers, to allow more efficient searches.
 
 thinker_t thinkerclasscap[NUMTHCLASS];
 
@@ -72,7 +72,7 @@ void P_InitThinkers(void)
 
 //
 // killough 8/29/98:
-// 
+//
 // We maintain separate threads of friends and enemies, to permit more
 // efficient searches.
 //
@@ -80,9 +80,9 @@ void P_InitThinkers(void)
 void P_UpdateThinker(thinker_t *thinker)
 {
   // find the class the thinker belongs to
-  
-  int class = thinker->function == P_MobjThinker && 
-    ((mobj_t *) thinker)->health > 0 && 
+
+  int class = thinker->function == P_MobjThinker &&
+    ((mobj_t *) thinker)->health > 0 &&
     (((mobj_t *) thinker)->flags & MF_COUNTKILL ||
      ((mobj_t *) thinker)->type == MT_SKULL) ?
     ((mobj_t *) thinker)->flags & MF_FRIEND ?
@@ -91,7 +91,7 @@ void P_UpdateThinker(thinker_t *thinker)
   // Remove from current thread
   thinker_t *th = thinker->cnext;
   (th->cprev = thinker->cprev)->cnext = th;
-  
+
   // Add to appropriate thread
   th = &thinkerclasscap[class];
   th->cprev->cnext = thinker;
@@ -173,7 +173,7 @@ void P_RemoveThinker(thinker_t *thinker)
  * P_SetTarget
  *
  * This function is used to keep track of pointer references to mobj thinkers.
- * In Doom, objects such as lost souls could sometimes be removed despite 
+ * In Doom, objects such as lost souls could sometimes be removed despite
  * their still being referenced. In Boom, 'target' mobj fields were tested
  * during each gametic, and any objects pointed to by them would be prevented
  * from being removed. But this was incomplete, and was slow (every mobj was
@@ -234,12 +234,12 @@ void P_Ticker (void)
    * killough 9/29/98: note that this ties in with basetic,
    * since G_Ticker does the pausing during recording or
    * playback, and compenates by incrementing basetic.
-   * 
+   *
    * All of this complicated mess is used to preserve demo sync.
    */
 
   if (paused || (menuactive && !demoplayback && !netgame &&
-		 players[consoleplayer].viewz != 1))
+     players[consoleplayer].viewz != 1))
     return;
 
   for (i=0; i<MAXPLAYERS; i++)
