@@ -1,7 +1,7 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
- * $Id: r_segs.c,v 1.12 2000/10/08 18:42:20 proff_fs Exp $
+ * $Id: r_segs.c,v 1.12.2.1 2002/07/20 18:08:37 proff_fs Exp $
  *
  *  PrBoom a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
@@ -9,7 +9,7 @@
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -22,7 +22,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -33,7 +33,7 @@
 // 4/25/98, 5/2/98 killough: reformatted, beautified
 
 static const char
-rcsid[] = "$Id: r_segs.c,v 1.12 2000/10/08 18:42:20 proff_fs Exp $";
+rcsid[] = "$Id: r_segs.c,v 1.12.2.1 2002/07/20 18:08:37 proff_fs Exp $";
 
 #include "doomstat.h"
 #include "r_main.h"
@@ -154,9 +154,9 @@ void R_RenderMaskedSegRange(drawseg_t *ds, int x1, int x2)
   lightnum = (R_FakeFlat(frontsector, &tempsec, NULL, NULL, false)
               ->lightlevel >> LIGHTSEGSHIFT)+extralight;
 
-	/* cph - ...what is this for? adding contrast to rooms?
-	 * It looks crap in outdoor areas */
-	if (fake_contrast) {
+  /* cph - ...what is this for? adding contrast to rooms?
+   * It looks crap in outdoor areas */
+  if (fake_contrast) {
     if (curline->v1->y == curline->v2->y)
       lightnum--;
     else
@@ -339,7 +339,7 @@ static void R_RenderSegLoop (void)
           dc_yh = yh;
           dc_texturemid = rw_midtexturemid;
           dc_source = R_GetColumn(midtexture, texturecolumn);
-	  dc_texheight = midtexheight;
+    dc_texheight = midtexheight;
           colfunc ();
           ceilingclip[rw_x] = viewheight;
           floorclip[rw_x] = -1;
@@ -363,7 +363,7 @@ static void R_RenderSegLoop (void)
                   dc_yh = mid;
                   dc_texturemid = rw_toptexturemid;
                   dc_source = R_GetColumn(toptexture,texturecolumn);
-		  dc_texheight = toptexheight;
+      dc_texheight = toptexheight;
                   colfunc ();
                   ceilingclip[rw_x] = mid;
                 }
@@ -406,12 +406,12 @@ static void R_RenderSegLoop (void)
               floorclip[rw_x] = yh+1;
             }
 
-	  // cph - if we completely blocked further sight through this column,
-	  // add this info to the solid columns array for r_bsp.c
-	  if ((markceiling || markfloor) && 
-	      (floorclip[rw_x] <= ceilingclip[rw_x] + 1)) {
-	    solidcol[rw_x] = 1; didsolidcol = 1;
-	  }
+    // cph - if we completely blocked further sight through this column,
+    // add this info to the solid columns array for r_bsp.c
+    if ((markceiling || markfloor) &&
+        (floorclip[rw_x] <= ceilingclip[rw_x] + 1)) {
+      solidcol[rw_x] = 1; didsolidcol = 1;
+    }
 
           // save texturecol for backdrawing of masked mid texture
           if (maskedtexture)
@@ -463,7 +463,7 @@ void R_StoreWallRange(const int start, const int stop)
     }
 
   if(curline->miniseg == false) // figgi -- skip minisegs
-  	curline->linedef->flags |= ML_MAPPED;
+    curline->linedef->flags |= ML_MAPPED;
 
 #ifdef GL_DOOM
   // proff 11/99: the rest of the calculations is not needed for OpenGL
@@ -589,45 +589,45 @@ void R_StoreWallRange(const int start, const int stop)
       ds_p->silhouette = 0;
 
       if (linedef->r_flags & RF_CLOSED) { /* cph - closed 2S line e.g. door */
-	// cph - killough's (outdated) comment follows - this deals with both 
-	// "automap fixes", his and mine
-	// killough 1/17/98: this test is required if the fix
-	// for the automap bug (r_bsp.c) is used, or else some
-	// sprites will be displayed behind closed doors. That
-	// fix prevents lines behind closed doors with dropoffs
-	// from being displayed on the automap.
+  // cph - killough's (outdated) comment follows - this deals with both
+  // "automap fixes", his and mine
+  // killough 1/17/98: this test is required if the fix
+  // for the automap bug (r_bsp.c) is used, or else some
+  // sprites will be displayed behind closed doors. That
+  // fix prevents lines behind closed doors with dropoffs
+  // from being displayed on the automap.
 
-	ds_p->silhouette = SIL_BOTH;
-	ds_p->sprbottomclip = negonearray;
-	ds_p->bsilheight = INT_MAX;
-	ds_p->sprtopclip = screenheightarray;
-	ds_p->tsilheight = INT_MIN;
+  ds_p->silhouette = SIL_BOTH;
+  ds_p->sprbottomclip = negonearray;
+  ds_p->bsilheight = INT_MAX;
+  ds_p->sprtopclip = screenheightarray;
+  ds_p->tsilheight = INT_MIN;
 
       } else { /* not solid - old code */
 
-	if (frontsector->floorheight > backsector->floorheight)
-	  {
-	    ds_p->silhouette = SIL_BOTTOM;
-	    ds_p->bsilheight = frontsector->floorheight;
-	  }
-	else
-	  if (backsector->floorheight > viewz)
-	    {
-	      ds_p->silhouette = SIL_BOTTOM;
-	      ds_p->bsilheight = INT_MAX;
-	    }
-	
-	if (frontsector->ceilingheight < backsector->ceilingheight)
-	  {
-	    ds_p->silhouette |= SIL_TOP;
-	    ds_p->tsilheight = frontsector->ceilingheight;
-	  }
-	else
-	  if (backsector->ceilingheight < viewz)
-	    {
-	      ds_p->silhouette |= SIL_TOP;
-	      ds_p->tsilheight = INT_MIN;
-	    }
+  if (frontsector->floorheight > backsector->floorheight)
+    {
+      ds_p->silhouette = SIL_BOTTOM;
+      ds_p->bsilheight = frontsector->floorheight;
+    }
+  else
+    if (backsector->floorheight > viewz)
+      {
+        ds_p->silhouette = SIL_BOTTOM;
+        ds_p->bsilheight = INT_MAX;
+      }
+
+  if (frontsector->ceilingheight < backsector->ceilingheight)
+    {
+      ds_p->silhouette |= SIL_TOP;
+      ds_p->tsilheight = frontsector->ceilingheight;
+    }
+  else
+    if (backsector->ceilingheight < viewz)
+      {
+        ds_p->silhouette |= SIL_TOP;
+        ds_p->tsilheight = INT_MIN;
+      }
       }
 
       worldhigh = backsector->ceilingheight - viewz;
@@ -678,19 +678,19 @@ void R_StoreWallRange(const int start, const int stop)
       if (worldhigh < worldtop)   // top texture
         {
           toptexture = texturetranslation[sidedef->toptexture];
-	  toptexheight = (linedef->r_flags & RF_TOP_TILE) ? 0 : textureheight[toptexture] >> FRACBITS;
+    toptexheight = (linedef->r_flags & RF_TOP_TILE) ? 0 : textureheight[toptexture] >> FRACBITS;
           rw_toptexturemid = linedef->flags & ML_DONTPEGTOP ? worldtop :
             backsector->ceilingheight+textureheight[sidedef->toptexture]-viewz;
-	  rw_toptexturemid += FixedMod(sidedef->rowoffset, textureheight[toptexture]);
+    rw_toptexturemid += FixedMod(sidedef->rowoffset, textureheight[toptexture]);
         }
 
       if (worldlow > worldbottom) // bottom texture
         {
           bottomtexture = texturetranslation[sidedef->bottomtexture];
-	  bottomtexheight = (linedef->r_flags & RF_BOT_TILE) ? 0 : textureheight[bottomtexture] >> FRACBITS;
+    bottomtexheight = (linedef->r_flags & RF_BOT_TILE) ? 0 : textureheight[bottomtexture] >> FRACBITS;
           rw_bottomtexturemid = linedef->flags & ML_DONTPEGBOTTOM ? worldtop :
             worldlow;
-	  rw_bottomtexturemid += FixedMod(sidedef->rowoffset, textureheight[bottomtexture]);
+    rw_bottomtexturemid += FixedMod(sidedef->rowoffset, textureheight[bottomtexture]);
         }
 
       // allocate space for masked texture tables
@@ -733,14 +733,14 @@ void R_StoreWallRange(const int start, const int stop)
         {
           int lightnum = (frontsector->lightlevel >> LIGHTSEGSHIFT)+extralight;
 
-	  /* cph - ...what is this for? adding contrast to rooms?
-	   * It looks crap in outdoor areas */
-	  if (fake_contrast) {
+    /* cph - ...what is this for? adding contrast to rooms?
+     * It looks crap in outdoor areas */
+    if (fake_contrast) {
           if (curline->v1->y == curline->v2->y)
             lightnum--;
           else if (curline->v1->x == curline->v2->x)
             lightnum++;
-	  }
+    }
 
           if (lightnum < 0)
             walllights = scalelight[0];
@@ -814,11 +814,11 @@ void R_StoreWallRange(const int start, const int stop)
     if (!(ds_p->silhouette & SIL_BOTTOM)) {
       ds_p->silhouette |= SIL_BOTTOM;
       ds_p->bsilheight = backsector->floorheight;
-    }     
+    }
     if (!(ds_p->silhouette & SIL_TOP)) {
       ds_p->silhouette |= SIL_TOP;
       ds_p->tsilheight = backsector->ceilingheight;
-    }     
+    }
   }
 
   // save sprite clipping info
